==> ydk-models-cisco-ios-xe-16.6.2.tar.gz: ydk-models-cisco-ios-xe-16.6.2/ydk/models/cisco_ios_xe/tailf_netconf_monitoring.py <==
""" tailf_netconf_monitoring 

This module augments ietf\-netconf\-monitoring with extra
monitoring data.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class CliConsole(Identity):
    """
    CLI on the console.
    
    

    """

    _prefix = 'tncm'
    _revision = '2016-11-24'

    def __init__(self):
        super(CliConsole, self).__init__("http://tail-f.com/yang/netconf-monitoring", "tailf-netconf-monitoring", "tailf-netconf-monitoring:cli-console")


class CliSsh(Identity):
    """
    CLI over SSH.
    
    

    """

    _prefix = 'tncm'
    _revision = '2016-11-24'

    def __init__(self):
        super(CliSsh, self).__init__("http://tail-f.com/yang/netconf-monitoring", "tailf-netconf-monitoring", "tailf-netconf-monitoring:cli-ssh")


class CliTcp(Identity):
    """
    CLI over TCP.
    
    

    """

    _prefix = 'tncm'
    _revision = '2016-11-24'

    def __init__(self):
        super(CliTcp, self).__init__("http://tail-f.com/yang/netconf-monitoring", "tailf-netconf-monitoring", "tailf-netconf-monitoring:cli-tcp")


class WebuiHttp(Identity):
    """
    WebUI over HTTP.
    
    

    """

    _prefix = 'tncm'
    _revision = '2016-11-24'

    def __init__(self):
        super(WebuiHttp, self).__init__("http://tail-f.com/yang/netconf-monitoring", "tailf-netconf-monitoring", "tailf-netconf-monitoring:webui-http")


class WebuiHttps(Identity):
    """
    WebUI over HTTPS.
    
    

    """

    _prefix = 'tncm'
    _revision = '2016-11-24'

    def __init__(self):
        super(WebuiHttps, self).__init__("http://tail-f.com/yang/netconf-monitoring", "tailf-netconf-monitoring", "tailf-netconf-monitoring:webui-https")


class NetconfTcp(Identity):
    """
    NETCONF over TCP.
    
    

    """

    _prefix = 'tncm'
    _revision = '2016-11-24'

    def __init__(self):
        super(NetconfTcp, self).__init__("http://tail-f.com/yang/netconf-monitoring", "tailf-netconf-monitoring", "tailf-netconf-monitoring:netconf-tcp")


class SnmpUdp(Identity):
    """
    SNMP over UDP.
    
    

    """

    _prefix = 'tncm'
    _revision = '2016-11-24'

    def __init__(self):
        super(SnmpUdp, self).__init__("http://tail-f.com/yang/netconf-monitoring", "tailf-netconf-monitoring", "tailf-netconf-monitoring:snmp-udp")


class RestHttp(Identity):
    """
    REST over HTTP.
    
    

    """

    _prefix = 'tncm'
    _revision = '2016-11-24'

    def __init__(self):
        super(RestHttp, self).__init__("http://tail-f.com/yang/netconf-monitoring", "tailf-netconf-monitoring", "tailf-netconf-monitoring:rest-http")


class RestHttps(Identity):
    """
    REST over HTTPS.
    
    

    """

    _prefix = 'tncm'
    _revision = '2016-11-24'

    def __init__(self):
        super(RestHttps, self).__init__("http://tail-f.com/yang/netconf-monitoring", "tailf-netconf-monitoring", "tailf-netconf-monitoring:rest-https")

==> ydk-models-cisco-ios-xe-16.8.1.tar.gz: ydk-models-cisco-ios-xe-16.8.1/ydk/models/cisco_ios_xe/tailf_netconf_monitoring.py <==
""" tailf_netconf_monitoring 

This module augments ietf\-netconf\-monitoring with extra
monitoring data.

"""
from collections import OrderedDict

from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class CliConsole(Identity):
    """
    CLI on the console.
    
    

    """

    _prefix = 'tncm'
    _revision = '2016-11-24'

    def __init__(self):
        super(CliConsole, self).__init__("http://tail-f.com/yang/netconf-monitoring", "tailf-netconf-monitoring", "tailf-netconf-monitoring:cli-console")


class CliSsh(Identity):
    """
    CLI over SSH.
    
    

    """

    _prefix = 'tncm'
    _revision = '2016-11-24'

    def __init__(self):
        super(CliSsh, self).__init__("http://tail-f.com/yang/netconf-monitoring", "tailf-netconf-monitoring", "tailf-netconf-monitoring:cli-ssh")


class CliTcp(Identity):
    """
    CLI over TCP.
    
    

    """

    _prefix = 'tncm'
    _revision = '2016-11-24'

    def __init__(self):
        super(CliTcp, self).__init__("http://tail-f.com/yang/netconf-monitoring", "tailf-netconf-monitoring", "tailf-netconf-monitoring:cli-tcp")


class WebuiHttp(Identity):
    """
    WebUI over HTTP.
    
    

    """

    _prefix = 'tncm'
    _revision = '2016-11-24'

    def __init__(self):
        super(WebuiHttp, self).__init__("http://tail-f.com/yang/netconf-monitoring", "tailf-netconf-monitoring", "tailf-netconf-monitoring:webui-http")


class WebuiHttps(Identity):
    """
    WebUI over HTTPS.
    
    

    """

    _prefix = 'tncm'
    _revision = '2016-11-24'

    def __init__(self):
        super(WebuiHttps, self).__init__("http://tail-f.com/yang/netconf-monitoring", "tailf-netconf-monitoring", "tailf-netconf-monitoring:webui-https")


class NetconfTcp(Identity):
    """
    NETCONF over TCP.
    
    

    """

    _prefix = 'tncm'
    _revision = '2016-11-24'

    def __init__(self):
        super(NetconfTcp, self).__init__("http://tail-f.com/yang/netconf-monitoring", "tailf-netconf-monitoring", "tailf-netconf-monitoring:netconf-tcp")


class SnmpUdp(Identity):
    """
    SNMP over UDP.
    
    

    """

    _prefix = 'tncm'
    _revision = '2016-11-24'

    def __init__(self):
        super(SnmpUdp, self).__init__("http://tail-f.com/yang/netconf-monitoring", "tailf-netconf-monitoring", "tailf-netconf-monitoring:snmp-udp")


class RestHttp(Identity):
    """
    REST over HTTP.
    
    

    """

    _prefix = 'tncm'
    _revision = '2016-11-24'

    def __init__(self):
        super(RestHttp, self).__init__("http://tail-f.com/yang/netconf-monitoring", "tailf-netconf-monitoring", "tailf-netconf-monitoring:rest-http")


class RestHttps(Identity):
    """
    REST over HTTPS.
    
    

    """

    _prefix = 'tncm'
    _revision = '2016-11-24'

    def __init__(self):
        super(RestHttps, self).__init__("http://tail-f.com/yang/netconf-monitoring", "tailf-netconf-monitoring", "tailf-netconf-monitoring:rest-https")
